# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fsai_grpc_api.protos import image_api_pb2 as fsai__grpc__api_dot_protos_dot_image__api__pb2


class ImageApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.FindOrCreateImage = channel.unary_unary(
                '/ImageApi/FindOrCreateImage',
                request_serializer=fsai__grpc__api_dot_protos_dot_image__api__pb2.ImageRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_image__api__pb2.ImageResponse.FromString,
                )
        self.GetImage = channel.unary_unary(
                '/ImageApi/GetImage',
                request_serializer=fsai__grpc__api_dot_protos_dot_image__api__pb2.GetImageRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_image__api__pb2.ImageObjectResponse.FromString,
                )
        self.GetImageStream = channel.unary_stream(
                '/ImageApi/GetImageStream',
                request_serializer=fsai__grpc__api_dot_protos_dot_image__api__pb2.GetImageRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_image__api__pb2.ImageBytes.FromString,
                )


class ImageApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def FindOrCreateImage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetImage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetImageStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ImageApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'FindOrCreateImage': grpc.unary_unary_rpc_method_handler(
                    servicer.FindOrCreateImage,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_image__api__pb2.ImageRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_image__api__pb2.ImageResponse.SerializeToString,
            ),
            'GetImage': grpc.unary_unary_rpc_method_handler(
                    servicer.GetImage,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_image__api__pb2.GetImageRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_image__api__pb2.ImageObjectResponse.SerializeToString,
            ),
            'GetImageStream': grpc.unary_stream_rpc_method_handler(
                    servicer.GetImageStream,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_image__api__pb2.GetImageRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_image__api__pb2.ImageBytes.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ImageApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ImageApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def FindOrCreateImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ImageApi/FindOrCreateImage',
            fsai__grpc__api_dot_protos_dot_image__api__pb2.ImageRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_image__api__pb2.ImageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ImageApi/GetImage',
            fsai__grpc__api_dot_protos_dot_image__api__pb2.GetImageRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_image__api__pb2.ImageObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetImageStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/ImageApi/GetImageStream',
            fsai__grpc__api_dot_protos_dot_image__api__pb2.GetImageRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_image__api__pb2.ImageBytes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
